@@ -5,7 +5,8 @@ use warnings;
 package Hash::Objectify;
 
 # ABSTRACT: Create objects from hashes on the fly
-our $VERSION = '0.002'; # VERSION
+
+our $VERSION = '0.004';
 
 use Carp;
 use Sub::Install;
@@ -37,7 +38,7 @@ sub import {
                 }
                 else {
                     my ( $caller, undef, $line ) = caller;
-                    my $cachekey = join "", keys %$ref;
+                    my $cachekey = join "", sort keys %$ref;
                     if ( !defined $CACHE{$caller}{$line}{$cachekey} ) {
                         no strict 'refs';
                         $package = $CACHE{$caller}{$line}{$cachekey} = "Hash::Objectified$COUNTER";
@@ -64,6 +65,7 @@ our $AUTOLOAD;
 
 sub can {
     my ( $self, $key ) = @_;
+    return unless ref $self && exists $self->{$key};
     $self->$key; # install accessor if not installed
     return $self->SUPER::can($key);
 }
@@ -96,7 +98,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -104,7 +106,7 @@ Hash::Objectify - Create objects from hashes on the fly
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -132,8 +134,6 @@ framework of your choice.
 Using Hash::Objectify is slower than accessing the keys of the hash directly, but
 does provide "typo protection" since a misspelled method is an error.
 
-=for Pod::Coverage method_names_here
-
 =head1 USAGE
 
 =head2 objectify
@@ -170,6 +170,8 @@ access to the keys of a blessed hash, you should make an explicit, shallow copy:
 
   my $copy = objectify {%$object};
 
+=for Pod::Coverage method_names_here
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -187,7 +189,7 @@ public review and contribution under the terms of the license.
 
 L<https://github.com/dagolden/hash-objectify>
 
-  git clone git://github.com/dagolden/hash-objectify.git
+  git clone https://github.com/dagolden/hash-objectify.git
 
 =head1 AUTHOR
 
